/* Copyright 2004 Acegi Technology Pty Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sf.acegisecurity.intercept.event;

import junit.framework.TestCase;

import net.sf.acegisecurity.BadCredentialsException;
import net.sf.acegisecurity.ConfigAttributeDefinition;
import net.sf.acegisecurity.MockMethodInvocation;
import net.sf.acegisecurity.providers.UsernamePasswordAuthenticationToken;


/**
 * Tests {@link AuthenticationFailureEvent}.
 *
 * @author Ben Alex
 * @version $Id$
 */
public class AuthenticationFailureEventTests extends TestCase {
    //~ Constructors ===========================================================

    public AuthenticationFailureEventTests() {
        super();
    }

    public AuthenticationFailureEventTests(String arg0) {
        super(arg0);
    }

    //~ Methods ================================================================

    public static void main(String[] args) {
        junit.textui.TestRunner.run(AuthenticationFailureEventTests.class);
    }

    public void testRejectsNulls() {
        try {
            AuthenticationFailureEvent event = new AuthenticationFailureEvent(null,
                    new ConfigAttributeDefinition(),
                    new UsernamePasswordAuthenticationToken("foo", "bar"),
                    new BadCredentialsException("error"));
            fail("Should have thrown IllegalArgumentException");
        } catch (IllegalArgumentException expected) {
            assertTrue(true);
        }

        try {
            AuthenticationFailureEvent event = new AuthenticationFailureEvent(new MockMethodInvocation(),
                    null,
                    new UsernamePasswordAuthenticationToken("foo", "bar"),
                    new BadCredentialsException("error"));
            fail("Should have thrown IllegalArgumentException");
        } catch (IllegalArgumentException expected) {
            assertTrue(true);
        }

        try {
            AuthenticationFailureEvent event = new AuthenticationFailureEvent(new MockMethodInvocation(),
                    new ConfigAttributeDefinition(), null,
                    new BadCredentialsException("error"));
            fail("Should have thrown IllegalArgumentException");
        } catch (IllegalArgumentException expected) {
            assertTrue(true);
        }

        try {
            AuthenticationFailureEvent event = new AuthenticationFailureEvent(new MockMethodInvocation(),
                    new ConfigAttributeDefinition(),
                    new UsernamePasswordAuthenticationToken("foo", "bar"), null);
            fail("Should have thrown IllegalArgumentException");
        } catch (IllegalArgumentException expected) {
            assertTrue(true);
        }
    }
}
